@@ -3,10 +3,10 @@
 
 ;; Author: NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-w3m.el,v 1.34 2010/08/02 15:21:05 skk-cvs Exp $
+;; Version: $Id: skk-w3m.el,v 1.35 2012/01/05 12:06:11 skk-cvs Exp $
 ;; Keywords: japanese
 ;; Created: Apr. 12, 2001 (oh, its my brother's birthday!)
-;; Last Modified: $Date: 2010/08/02 15:21:05 $
+;; Last Modified: $Date: 2012/01/05 12:06:11 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -314,7 +314,7 @@ w3m  backend ưƤʤ)")
 
 (defun skk-w3m-set-process-coding-system (coding-system)
   (static-cond
-   ((eq skk-emacs-type 'xemacs)
+   ((featurep 'xemacs)
     (set-process-input-coding-system skk-w3m-process coding-system)
     (set-process-output-coding-system skk-w3m-process coding-system))
    (t
