@@ -5,10 +5,10 @@
 
 ;; Author: NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-annotation.el,v 1.236 2013/01/13 09:45:48 skk-cvs Exp $
+;; Version: $Id: skk-annotation.el,v 1.241 2014/10/13 05:15:04 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
 ;; Created: Oct. 27, 2000.
-;; Last Modified: $Date: 2013/01/13 09:45:48 $
+;; Last Modified: $Date: 2014/10/13 05:15:04 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -115,7 +115,7 @@
 ;;
 ;; (setq skk-annotation-lookup-lookup t)
 ;;
-;; <Mac OS X $B!V<-=q!W%5!<%S%9$+$i$N%"%N%F!<%7%g%s(B>
+;; <Apple OS X $B!V<-=q!W%5!<%S%9$+$i$N%"%N%F!<%7%g%s(B>
 ;;
 ;; Mac $B$N<-=q%"%W%j(B (Dictionary.app) $B$G$OI8=`$G9q8l<-E5$J$IMxMQ$G$-$^$9!#(B
 ;; $B$3$N$&$AM%@h=g0L$N9b$$<-=q$+$i%"%N%F!<%7%g%s$r<hF@$9$k5!G=$,MxMQ$G$-$^(B
@@ -198,6 +198,7 @@
   (autoload 'python-send-command "python")
   (autoload 'python-send-string "python")
   (autoload 'python-check-comint-prompt "python")
+  (autoload 'python-proc "python")
   (autoload 'html2text "html2text")
   (autoload 'html2text-delete-tags "html2text")
   (autoload 'url-hexify-string "url-util")
@@ -207,6 +208,8 @@
   (require 'compile)
   (require 'comint)
   (defvar python-buffer)
+  (defvar python-shell-prompt-regexp)
+  (defvar python-shell-buffer-name)
   (defvar mule-version)
   (defvar html2text-remove-tag-list)
   (defvar html2text-format-tag-list))
@@ -773,7 +776,7 @@ NO-PREVIOUS-ANNOTATION $B$r;XDj(B (\\[Universal-Argument] \\[skk-annotation-ad
 			  (setq exit t)
 			  (apply (car url) (cdr url)))
 			 (t
-			  (browse-url url))))
+			  (funcall skk-annotation-browser-function url))))
 		 (skk-message "$BCm<a$N%=!<%9$r%V%i%&%:$7$F$$$^$9(B..."
 			      "Browsing originals for the current notes..."))
 		(t
@@ -913,7 +916,7 @@ NO-PREVIOUS-ANNOTATION $B$r;XDj(B (\\[Universal-Argument] \\[skk-annotation-ad
 (defun skk-annotation-lookup-region-or-at-point (&optional prefix-arg
 							   start end)
   "$BA*BrNN0h$^$?$O%]%$%s%H0LCV$NC18l$r<-=q$GD4$Y$k!#(B
-$B<-=q$H$7$F$O(B lookup.el$B!"(BMac OS X $B$N<-=q%5!<%S%9!"(BWikipedia/Wikitionary $B$J$I$,(B
+$B<-=q$H$7$F$O(B lookup.el$B!"(BApple OS X $B$N<-=q%5!<%S%9!"(BWikipedia/Wikitionary $B$J$I$,(B
 $BMxMQ$5$l$k!#(B
 
 $BNN0h$,A*Br$5$l$F$$$J$1$l$PC18l$N;O$a$H=*$o$j$r?dB,$7$FD4$Y$k!#(B
@@ -952,7 +955,7 @@ NO-PREVIOUS-ANNOTATION $B$r;XDj(B (\\[Universal-Argument] \\[skk-annotation-ad
       (skk-annotation-show (or note "") word sources))))
 
 
-;;; Mac OS X $B<-=q%5!<%S%94XO"5!G=(B
+;;; Apple OS X $B<-=q%5!<%S%94XO"5!G=(B
 (defsubst skkannot-DictServ-command (word)
   (format skkannot-DictServ-cmd-format-str word "%" "%"))
 
@@ -974,13 +977,34 @@ NO-PREVIOUS-ANNOTATION $B$r;XDj(B (\\[Universal-Argument] \\[skk-annotation-ad
       ;; as to make sure we terminate the multiline instruction.
       (comint-send-string proc "\n"))))
 
+(eval-and-compile
+  (defsubst skkannot-emacs-24_3-or-later ()
+    (or (> emacs-major-version 24)
+	(and (= emacs-major-version 24)
+	     (>= emacs-minor-version 3)))))
+
+(defun skkannot-py-check-comint-prompt (&optional proc)
+  "Return non-nil if and only if there's a normal prompt in the inferior buffer.
+If there isn't, it's probably not appropriate to send input to return Eldoc
+information etc.  If PROC is non-nil, check the buffer for that process."
+  (cond
+   ((eval-when-compile (skkannot-emacs-24_3-or-later))
+    (with-current-buffer (process-buffer (or proc (python-proc)))
+      (save-excursion
+	(save-match-data
+	  (re-search-backward (concat python-shell-prompt-regexp " *\\=")
+			      nil t)))))
+   (t
+    (python-check-comint-prompt))))
+
 (declare-function compilation-forget-errors "compile")
 (defun skkannot-py-send-command (command)
   "Like `skkannot-py-send-string' but resets `compilation-shell-minor-mode'."
   (when (or (eval-when-compile (and (featurep 'emacs)
 				    (= emacs-major-version 22)))
-	    (python-check-comint-prompt (get-buffer-process
-					 skkannot-py-buffer)))
+	    (skkannot-py-check-comint-prompt (get-buffer-process
+					      skkannot-py-buffer))
+	    t)
     (with-current-buffer skkannot-py-buffer
       (goto-char (point-max))
       (compilation-forget-errors)
@@ -996,11 +1020,19 @@ NO-PREVIOUS-ANNOTATION $B$r;XDj(B (\\[Universal-Argument] \\[skk-annotation-ad
     skkannot-py-buffer)
    (t
     ;; python + readline $B$G(B UTF-8 $B$NF~NO$r$9$k$?$a$K(B LANG $B$N@_Dj$,I,MW!#(B
-    (let ((env (getenv "LANG"))
-	  (orig-py-buffer (default-value 'python-buffer)))
+    (let* ((env (getenv "LANG"))
+	   python-buffer orig-py-buffer)
+      (unless (eval-when-compile (skkannot-emacs-24_3-or-later))
+	;; Emacs 24.2 or earlier
+	(setq orig-py-buffer (default-value 'python-buffer)))
       (unless (equal env "Ja_JP.UTF-8")
 	(setenv "LANG" "ja_JP.UTF-8"))
-      (run-python skk-annotation-python-program t t)
+      (save-window-excursion
+	(run-python skk-annotation-python-program t t))
+      (when (eval-when-compile (skkannot-emacs-24_3-or-later))
+	;; Emacs 24.3 or later
+	(setq python-buffer (get-buffer (format "*%s*" python-shell-buffer-name))
+	      orig-py-buffer (default-value 'python-buffer)))
       (setenv "LANG" env)
       (with-current-buffer python-buffer
 	(rename-buffer "  *skk python")
@@ -1742,16 +1774,18 @@ wgCategories.+\\($B[#Kf$52sHr(B\\|[Dd]isambiguation\\).+$" nil t)))
   (goto-char (point-min))
   (when (re-search-forward "^Content-Encoding: gzip$" nil t)
     ;; html $B$,(B gzip $B05=L$GAw$i$l$FMh$?>l9g(B
-    (let ((gzip (executable-find "gzip")))
-      (unless gzip
-	(error "$B$3$NFbMF$rI=<($9$k$K$O(B %s $B$,I,MW$G$9(B" "gzip"))
-      (while (and (not (looking-at "^\n"))
-		  (not (eobp)))
-	(forward-line 1))
-      (forward-line 1)
-      (when (< (point) (point-max))
-	(let ((coding-system-for-write 'binary))
-	  (call-process-region (point) (point-max) gzip t t t "-cd")))))
+    (unless (fboundp 'url-handle-content-transfer-encoding)
+      ;; Emacs 24.3 or earlier
+      (let ((gzip (executable-find "gzip")))
+	(unless gzip
+	  (error "$B$3$NFbMF$rI=<($9$k$K$O(B %s $B$,I,MW$G$9(B" "gzip"))
+	(while (and (not (looking-at "^\n"))
+		    (not (eobp)))
+	  (forward-line 1))
+	(forward-line 1)
+	(when (< (point) (point-max))
+	  (let ((coding-system-for-write 'binary))
+	    (call-process-region (point) (point-max) gzip t t t "-cd"))))))
   (goto-char (point-max))
   (search-backward "</html>" nil t))
 
