@@ -5,9 +5,9 @@
 
 ;; Author: Masatake YAMATO <masata-y@is.aist-nara.ac.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-cursor.el,v 1.44 2011/06/03 22:44:55 skk-cvs Exp $
+;; Version: $Id: skk-cursor.el,v 1.46 2013/01/13 09:45:48 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2011/06/03 22:44:55 $
+;; Last Modified: $Date: 2013/01/13 09:45:48 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -38,7 +38,7 @@
   (require 'skk-vars))
 
 (eval-and-compile
-  (when skk-running-gnu-emacs
+  (when (featurep 'emacs)
     (require 'ccc)))
 
 ;; Functions.
@@ -58,7 +58,7 @@
     (skk-cursor-default-color))
    ;; `skk-start-henkan' $B$NCf$G$O!"(Bskk-j-mode $B%U%i%0$rN)$F$J$,$i!"(B
    ;; skk-abbrev-mode $B%U%i%0$bN)$F$F$$$k(B ($BJQ498e!"D>8e$KF~NO$9$kJ8(B
-   ;; $B;z$,85$NF~NO%b!<%I$K$F9T$J$o$l$k$h$&$K(B)$B!#=>$$!"(Bskk-abbrev-mode
+   ;; $B;z$,85$NF~NO%b!<%I$K$F9T$o$l$k$h$&$K(B)$B!#=>$$!"(Bskk-abbrev-mode
    ;; $B%U%i%0$N%A%'%C%/$NM%@hEY$r>e$2$k!#(B
    (skk-abbrev-mode
     skk-cursor-abbrev-color)
