@@ -4,9 +4,9 @@
 
 ;; Author: NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-develop.el,v 1.31 2012/12/08 23:26:22 skk-cvs Exp $
+;; Version: $Id: skk-develop.el,v 1.33 2013/10/15 12:49:32 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2012/12/08 23:26:22 $
+;; Last Modified: $Date: 2013/10/15 12:49:32 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -104,38 +104,44 @@ mail-user-agent $B$r@_Dj$9$k$3$H$K$h$j9%$_$N%a!<%k%$%s%?!<%U%'%$%9$r;HMQ$9$k$3$
  'before-init-hook
  (lambda ()
    (eval-after-load "font-lock"
-     '(setq lisp-font-lock-keywords-2
+     ;; `lisp-font-lock-keywords-2' is an alias for `lisp-el-font-lock-keywords-2'.
+     ;; `lisp-font-lock-keywords-2' is obsolete since 24.4;
+     ;;                             use `lisp-el-font-lock-keywords-2' instead.
+     '(set (if (boundp 'lisp-el-font-lock-keywords-2)
+	       'lisp-el-font-lock-keywords-2
+	     'lisp-font-lock-keywords-2)
 	    (nconc
-	     (list
-	      (list
-	       (concat "(\\(\\(skk-\\)?def\\("
-		       ;; Function type declarations.
-		       "\\(un-cond\\|subst-cond\\|advice\\|"
-		       "macro-maybe\\|alias-maybe\\|un-maybe\\)\\|"
-		       ;; Variable type declarations.
-		       "\\(var\\|localvar\\)"
-		       "\\)\\)\\>"
-		       ;; Any whitespace and defined object.
-		       "[ \t'\(]*"
-		       "\\(\\sw+\\)?")
-	       '(1 font-lock-keyword-face)
-	       '(6 (cond ((match-beginning 4) font-lock-function-name-face)
-			 ((match-beginning 5) font-lock-variable-name-face))
-		   nil t)))
-	     (list
-	      (list
-	       (concat "("
-		       (regexp-opt '("skk-save-point"
-				     "skk-with-point-move"
-				     "skk-loop-for-buffers")
-				   t)
-		       "\\>")
-	       '(1 font-lock-keyword-face)))
-	     (list
-	      (list
-	       "(\\(skk-error\\)\\>"
-	       '(1 font-lock-warning-face)))
-	     lisp-font-lock-keywords-2)))
+	     (list (list (concat "(\\(\\(skk-\\)?def\\("
+				 ;; Function type declarations.
+				 "\\(un-cond\\|subst-cond\\|advice\\|"
+				 "macro-maybe\\|alias-maybe\\|un-maybe\\)\\|"
+				 ;; Variable type declarations.
+				 "\\(var\\|localvar\\)"
+				 "\\)\\)\\>"
+				 ;; Any whitespace and defined object.
+				 "[ \t'\(]*"
+				 "\\(\\sw+\\)?")
+			 '(1 font-lock-keyword-face)
+			 '(6 (cond ((match-beginning 4) font-lock-function-name-face)
+				   ((match-beginning 5) font-lock-variable-name-face))
+			     nil t)))
+
+	     (list (list (concat "("
+				 (regexp-opt '("skk-save-point"
+					       "skk-with-point-move"
+					       "skk-loop-for-buffers")
+					     t)
+				 "\\>")
+			 '(1 font-lock-keyword-face)))
+
+	     (list (list "(\\(skk-error\\)\\>"
+			 '(1 font-lock-warning-face)))
+
+	     (symbol-value (if (boundp 'lisp-el-font-lock-keywords-2)
+			       'lisp-el-font-lock-keywords-2
+			     'lisp-font-lock-keywords-2))
+
+	     )))
    ;;
    (put 'skk-deflocalvar 'doc-string-elt 3)
    (put 'skk-defadvice 'doc-string-elt 3)
