@@ -34,16 +34,7 @@
   (require 'skk-vars)
   (require 'skk-macs)
 
-  (defvar tool-bar-border)
-
-  (when (= emacs-major-version 21)
-    (defalias 'window-inside-pixel-edges 'ignore)
-    (defalias 'posn-at-point 'ignore)))
-
-(when (eval-when-compile (= emacs-major-version 21))
-  ;; Emacs 21 $B$G$O(B `make-temp-file' $B$N@H<e@-$KBP=h$9$k$?$a(B
-  ;; poe $B$rI,MW$H$9$k!#(B
-  (require 'poe))
+  (defvar tool-bar-border))
 
 (eval-and-compile
   (autoload 'mouse-avoidance-banish-destination "avoid")
@@ -209,7 +200,6 @@
 	      (boundp 'mac-carbon-version-string) ; Carbon Emacs
 	      (featurep 'ns) ; Cocoa Emacs
 	      (and (eq window-system 'x)
-		   (>= emacs-major-version 22)
 		   (boundp 'gtk-version-string)
 		   (stringp (symbol-value 'gtk-version-string))
 		   (string< "2.0" (symbol-value 'gtk-version-string))))
@@ -260,19 +250,18 @@
 
 (defun skk-emacs-circulate-modes (&optional arg)
   (interactive "P")
-  (cond
-   (skk-henkan-mode
-    nil)
-   ((not skk-mode)
-    (skk-mode arg))
-   (skk-j-mode
-    (if skk-katakana
-	(skk-jisx0208-latin-mode arg)
-      (skk-toggle-kana arg)))
-   (skk-jisx0208-latin-mode
-    (skk-latin-mode arg))
-   (skk-latin-mode
-    (skk-j-mode-on))))
+  (cond (skk-henkan-mode
+	 nil)
+	((not skk-mode)
+	 (skk-mode arg))
+	(skk-j-mode
+	 (if skk-katakana
+	     (skk-jisx0208-latin-mode arg)
+	   (skk-toggle-kana arg)))
+	(skk-jisx0208-latin-mode
+	 (skk-latin-mode arg))
+	(skk-latin-mode
+	 (skk-j-mode-on))))
 
 (defun skk-emacs-info ()
   (interactive)
@@ -290,23 +279,19 @@
 (defun skk-emacs-prepare-modeline-properties ()
   (setq skk-icon
 	(let* ((dir (ignore-errors
-		      (file-name-directory
-		       (if (eval-when-compile (>= emacs-major-version 22))
-			   ;; Emacs 22 $B0J9_(B `locate-file' $B$,MxMQ2DG=!#(B
-			   (or (locate-file "skk/skk.xpm"
-					    (list (expand-file-name
-						   "../../.."
-						   data-directory)))
-			       (locate-file "skk/skk.xpm"
-					    (list data-directory)))
-			 ;; Emacs 21
-			 skk-tut-file))))
+		     (file-name-directory
+		      (or (locate-file "skk/skk.xpm"
+				       (list (expand-file-name
+					      "../../.."
+					      data-directory)))
+			  (locate-file "skk/skk.xpm"
+				       (list data-directory))))))
 	       (image (when dir
 			(find-image
 			 `((:type xpm
 				  :file ,(expand-file-name "skk.xpm" dir)
 				  :ascent center)))))
-	       (string "dummy"))
+	       (string "skk"))
 	  (if (and skk-show-icon window-system image)
 	      (apply 'propertize string
 		     (cons 'display (cons image skk-emacs-modeline-property)))
@@ -472,22 +457,15 @@
        (< emacs-major-version 24)))
 
 (defun skk-tooltip-show-at-point (text &optional situation)
-  "TEXT $B$r(B tooltip $B$GI=<($9$k!#(B
-$B%*%W%7%g%J%k0z?t(B SITUATION $B$,%7%s%\%k(B annotation $B$G$"$l$P!"(B
-$B%7%s%\%k(B listing $B$G$"$l$P!"(B"
+  "TEXT $B$r(B tooltip $B$GI=<($9$k!#(B"
   (require 'tooltip)
-  ;; Emacs 21 $B$G$O!"%^%&%9%]%$%s%?Hs0MB8$N0LCV7hDj$,$G$-$J$$(B ($B$H;W$o$l$k(B)
-  (when (eq emacs-major-version 21)
-    (setq skk-tooltip-mouse-behavior 'follow))
-  ;;
   (let* ((P (cdr (skk-emacs-mouse-position)))
 	 (oP (cdr (mouse-position)))
 	 event
 	 parameters
 	 (avoid-destination (if (memq skk-tooltip-mouse-behavior
 				      '(avoid avoid-maybe banish))
-				(mouse-avoidance-banish-destination)
-			       nil))
+				(mouse-avoidance-banish-destination)))
 	 win
 	 tip-destination
 	 fontsize
@@ -496,8 +474,7 @@
 	 spacing border-width internal-border-width
 	 text-width text-height
 	 screen-width screen-height
-	 (inhibit-quit t)
-	 (tooltip-use-echo-area nil))
+	 (inhibit-quit t))
     ;;
     (when (null (car P))
       (unless (memq skk-tooltip-mouse-behavior '(avoid-maybe banish nil))
@@ -562,7 +539,7 @@
 				      0)
 
 	    ;; $B0J2<(B left $B$H(B top $B$O!"(BX Window System $B2<$G$O2hLLA4BN$NCf$G$N:BI8$r(B
-	    ;; $B;XDj$9$k!#(B Mac OS X $B$K$*$$$F$b!"(BCarbon Emacs 22.3 $B$G$OF1MM$@$,(B
+	    ;; $B;XDj$9$k!#(B Apple OS X $B$K$*$$$F$b!"(BCarbon Emacs 22.3 $B$G$OF1MM$@$,(B
 	    ;; Cocoa Emacs 23.2 $B$G$O(B Emacs $B%U%l!<%`Fb$G$N:BI8$r;XDj$9$kI,MW$,$"$k!#(B
 
 	    ;; x $B:BI8(B ($B:8$+$i$N(B)
@@ -620,7 +597,8 @@
 			    (* (frame-pixel-width)))))
 	    (when (and (<= left mouse-x) (<= mouse-x right))
 	      ;; $B%^%&%9%]%$%s%?$HHo$j$=$&$J$H$-(B
-	      (setq left (- left (- right mouse-x) fontsize))))))))
+	      (setq left (- left (- right mouse-x) fontsize))))))
+      )) ; END **$B%^%&%9%]%$%s%?$K0MB8$;$:(B tooptip $B$N0LCV$r7hDj$9$k(B**
     ;;
     (setq parameters (if (eq skk-tooltip-mouse-behavior 'follow)
 			 skk-tooltip-parameters
@@ -679,10 +657,10 @@ TEXT $B$K$O(B `skk-tooltip-face' $B$,E,MQ$5$l$k!#(B"
 	  (setq fg (face-attribute 'tooltip :foreground))
 	  (setq bg (face-attribute 'tooltip :background))
 	  (when (stringp fg)
-	    (setq params (tooltip-set-param params 'foreground-color fg))
-	    (setq params (tooltip-set-param params 'border-color fg)))
+	    (setq params (skk-put-alist 'foreground-color fg params))
+	    (setq params (skk-put-alist 'border-color fg params)))
 	  (when (stringp bg)
-	    (setq params (tooltip-set-param params 'background-color bg))))
+	    (setq params (skk-put-alist 'background-color bg params))))
 	;;
 	(when (facep skk-tooltip-face)
 	  (setq text (propertize text 'face skk-tooltip-face)))
@@ -747,7 +725,7 @@ TEXT $B$K$O(B `skk-tooltip-face' $B$,E,MQ$5$l$k!#(B"
 		      (<= ch (cdr skkdic-jisx0208-hiragana-block))
 		      (setq code (encode-char ch 'japanese-jisx0208)))
 		 (aset vec i (- (logand code #xFF) 32)))
-		((and (eval-when-compile (<= emacs-major-version 22))
+		((and (eval-when-compile (= emacs-major-version 22))
 		      (setq code (split-char ch))
 		      (eq (car code) 'japanese-jisx0208)
 		      (= (nth 1 code) skkdic-jisx0208-hiragana-block))
