@@ -4,9 +4,9 @@
 ;; Copyright (C) 1993-2000 Free Software Foundation, Inc.
 
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-macs.el,v 1.192 2013/01/13 09:45:48 skk-cvs Exp $
+;; Version: $Id: skk-macs.el,v 1.199 2013/03/28 11:55:19 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2013/01/13 09:45:48 $
+;; Last Modified: $Date: 2013/03/28 11:55:19 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -117,14 +117,12 @@ doesn't give arguments of `interactive'. See `interactive' for details."
  ARG $B$O(B `message' $B4X?t$NBh#20z?t0J9_$N0z?t$H$7$FEO$5$l$k!#(B"
   (append
    (if arg
-       (list 'message (list 'if
-			    'skk-japanese-message-and-error
-			    japanese
-			    english))
-     (list 'message "%s" (list 'if
-			       'skk-japanese-message-and-error
-			       japanese
-			       english)))
+       `(message (if skk-japanese-message-and-error
+		     ,japanese
+		   ,english))
+     `(message "%s" (if skk-japanese-message-and-error
+			,japanese
+		      ,english)))
    arg))
 
 (defmacro skk-error (japanese english &rest arg)
@@ -134,14 +132,12 @@ doesn't give arguments of `interactive'. See `interactive' for details."
  ARG $B$O(B `error' $B4X?t$NBh#20z?t0J9_$N0z?t$H$7$FEO$5$l$k!#(B"
   (append
    (if arg
-       (list 'error (list 'if
-			  'skk-japanese-message-and-error
-			  japanese
-			  english))
-     (list 'error "%s" (list 'if
-			     'skk-japanese-message-and-error
-			     japanese
-			     english)))
+       `(error (if skk-japanese-message-and-error
+		   ,japanese
+		 ,english))
+     `(error "%s" (if skk-japanese-message-and-error
+		      ,japanese
+		    ,english)))
    arg))
 
 (defmacro skk-yes-or-no-p (japanese english)
@@ -151,24 +147,24 @@ doesn't give arguments of `interactive'. See `interactive' for details."
 `yes-or-no-p' $B$N0z?t(B PROMPT $B$,J#;($KF~$l9~$s$G$$$k>l9g$O(B `skk-yes-or-no-p' $B$r(B
 $B;H$&$h$j$b%*%j%8%J%k$N(B `yes-or-no-p' $B$r;HMQ$7$?J}$,%3!<%I$,J#;($K$J$i$J$$>l9g(B
 $B$,$"$k!#(B"
-  (list 'yes-or-no-p (list 'if 'skk-japanese-message-and-error
-			   japanese english)))
+  `(yes-or-no-p (if skk-japanese-message-and-error
+		    ,japanese ,english)))
 
 (defmacro skk-y-or-n-p (japanese english)
   "$B%f!<%6$K(B \"y or n\" $B$r<ALd$7!"Ez$($,(B \"y\" $B$@$C$?$i(B t $B$rJV$9!#(B
 `skk-japanese-message-and-error' $B$,(B non-nil $B$G$"$l$P(B JAPANESE $B$r!"(B nil $B$G$"$l(B
 $B$P(B ENGLISH $B$r(B PROMPT $B$H$7$F(B `y-or-n-p' $B$r<B9T$9$k!#(B"
-  (list 'y-or-n-p (list 'if 'skk-japanese-message-and-error
-			japanese english)))
+  `(y-or-n-p (if skk-japanese-message-and-error
+		 ,japanese ,english)))
 
 (defmacro skk-set-marker (marker position &optional buffer)
   "$B%^!<%+(B MARKER $B$r(B BUFFER $B$N(B POSITION $B$K0\F0$9$k!#(B
 BUFFER $B$N%G%#%U%)%k%HCM$O%+%l%s%H%P%C%U%!$G$"$k!#(B
 MARKER $B$,(B nil $B$@$C$?$i!"?75,%^!<%+!<$r:n$C$FBeF~$9$k!#(B"
-  (list 'progn
-	(list 'if (list 'not marker)
-	      (list 'setq marker (list 'make-marker)))
-	(list 'set-marker marker position buffer)))
+  `(progn
+     (if (not ,marker)
+	 (setq ,marker (make-marker)))
+     (set-marker ,marker ,position ,buffer)))
 
 (defmacro skk-with-point-move (&rest form)
   "$B%]%$%s%H$r0\F0$9$k$,%U%C%/$r<B9T$7$F$[$7$/$J$$>l9g$K;H$&!#(B"
@@ -269,6 +265,12 @@ MARKER $B$,(B nil $B$@$C$?$i!"?75,%^!<%+!<$r:n$C$FBeF~$9$k!#(B"
 	 '(inactivate-input-method))
 	))
 
+(defmacro skk-facep (face)
+  (cond ((featurep 'xemacs)
+	 `(find-face ,face))
+	(t
+	 `(facep ,face))))
+
 
 ;;; functions.
 ;; version dependent
@@ -276,22 +278,53 @@ MARKER $B$,(B nil $B$@$C$?$i!"?75,%^!<%+!<$r:n$C$FBeF~$9$k!#(B"
 
 (when (eval-when-compile (and (featurep 'emacs)
 			      (= emacs-major-version 22)))
-  (defalias 'characterp 'char-valid-p))
+  ;; GNU Emacs 22 $B$^$G(B
+  ;; . char-valid-p is a built-in function in `C source code'.
+  ;;     (char-valid-p OBJECT &optional GENERICP)
+  ;;   Return t if OBJECT is a valid normal character.
+  ;;   If optional arg GENERICP is non-nil, also return t if OBJECT is
+  ;;   a valid generic character.
+  (defalias 'characterp 'char-valid-p)
+
+  ;; GNU Emacs 23 $B$+$i(B
+  ;; . char-valid-p is an alias for `characterp' in `mule.el'.
+  ;;     (char-valid-p OBJECT &optional IGNORE)
+  ;;   This function is obsolete since 23.1;
+  ;;   use `characterp' instead.
+
+  ;; . characterp is a built-in function in `C source code'.
+  ;;     (characterp OBJECT &optional IGNORE)
+  ;;   Return non-nil if OBJECT is a character.
+  )
 
 (when (eval-when-compile (featurep 'emacs))
+  ;; int-char() $B$,=P8=$9$k$N$O(B skk-compute-henkan-lists() $B$N$_(B
+  ;; XEmacs $B$G$O(B int-char() $B$OI8=`!)(B
   (defalias 'int-char 'identity))
 
-(when (eval-when-compile (featurep 'emacs))
-  (defun string-to-char-list (string)
-    "Return a list of which elements are characters in the STRING."
-    (mapcar #'identity string)))
+;;; string-to-char-list $B$,=P8=$9$k$N$O(B 9 $B9T2<$N(B defalias $B$N$_(B
+;;; $B$h$C$F(B string-to-int-list $B$NDj5A$rJQ99$7$F$7$^$&(B
+;; (when (eval-when-compile (featurep 'emacs))
+;;   (defun string-to-char-list (string)
+;;     "Return a list of which elements are characters in the STRING."
+;;     (mapcar #'identity string)))
 
-(when (eval-when-compile (featurep 'emacs))
-  (defalias 'string-to-int-list 'string-to-char-list))
+;;; string-to-int-list() $B$NDj5A$r(B macro $B$XJQ99(B
+;; (when (eval-when-compile (featurep 'emacs))
+;;   ;; (defalias 'string-to-int-list 'string-to-char-list))
+;;   (defun string-to-int-list (string)
+;;     "Return a list of which elements are characters in the STRING."
+;;     (mapcar #'identity string)))
+;;
+;; (when (eval-when-compile (featurep 'xemacs))
+;;   (defun string-to-int-list (string)
+;;     (mapcar #'char-int string)))
 
-(when (eval-when-compile (featurep 'xemacs))
-  (defun string-to-int-list (str)
-    (mapcar #'char-int str)))
+(defmacro string-to-int-list (string)
+  (cond ((featurep 'xemacs)
+	 `(mapcar #'char-int ,string))	; XEamcs
+	(t
+	 `(mapcar #'identity ,string)))) ; GNU Emacs
 
 (when (eval-when-compile (featurep 'emacs))
   (defun character-to-event (ch)
@@ -554,12 +587,11 @@ BUFFER defaults to the current buffer."
     (local-variable-p variable (or buffer (current-buffer))))))
 
 (defun skk-face-proportional-p (face)
-  (cond
-   ((eval-when-compile (featurep 'xemacs))
-    (face-proportional-p face))
-   (t
-    (or (face-equal face 'variable-pitch)
-	(eq (face-attribute face :inherit) 'variable-pitch)))))
+  (cond ((eval-when-compile (featurep 'xemacs))
+	 (face-proportional-p face))
+	(t
+	 (or (face-equal face 'variable-pitch)
+	     (eq (face-attribute face :inherit) 'variable-pitch)))))
 
 (defun skk-event-key (event)
   "$B%$%Y%s%H(B EVENT $B$rH/@8$7$?F~NO$N>pJs$r<hF@$9$k!#(B"
@@ -973,11 +1005,12 @@ BUFFER defaults to the current buffer."
 (defsubst skk-get-last-henkan-datum (key)
   (cdr (assq key skk-last-henkan-data)))
 
-(defsubst skk-put-last-henkan-datum (key val)
-  (let ((e (assq key skk-last-henkan-data)))
-    (if e
-	(setcdr e val)
-      (push (cons key val) skk-last-henkan-data))))
+;;; 2013-3-18 $B$I$3$+$i$b;2>H$5$l$F$*$i$:(B
+;; (defsubst skk-put-last-henkan-datum (key val)
+;;   (let ((e (assq key skk-last-henkan-data)))
+;;     (if e
+;; 	(setcdr e val)
+;;       (push (cons key val) skk-last-henkan-data))))
 
 (defun skk-put-last-henkan-data (alist)
   (let (e)
