@@ -7,9 +7,9 @@
 
 ;; Author: Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-tut.el,v 1.92 2013/03/20 06:53:31 skk-cvs Exp $
+;; Version: $Id: skk-tut.el,v 1.94 2014/09/18 14:01:52 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2013/03/20 06:53:31 $
+;; Last Modified: $Date: 2014/09/18 14:01:52 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -309,6 +309,7 @@
     (skk-verbose . nil)
     (debug-on-error . nil)
     (skk-show-mode-show . nil)
+    (skk-show-mode-enable . nil)
 
     ;; not user variables but to be localized.
     (skk-insert-new-word-function . nil)
@@ -891,19 +892,22 @@ tutorial /$B%A%e!<%H%j%"%k(B/
 	    (insert
 	     (let ((next " `\\[skktut-next-question]'")
 		   (quit " `\\[skk-tutorial-quit]'")
-		   (skip " `\\[skktut-skip-question]'"))
+		   (skip " `\\[skktut-skip-question]'")
+		   (sow  " `\\[scroll-other-window]'"))
 	       (substitute-command-keys
 		(if skktut-japanese-tut
 		    (concat
-		     "* $BEz$,$G$-$?$i(B" next "; $BESCf$G$d$a$k$K$O(B" quit
+		     "* $BEz$,$G$-$?$i(B" next "\n"
+		     "* $BESCf$G$d$a$k$K$O(B" quit "\n"
 		     (if (/= skktut-question-count skktut-question-numbers)
-			 (concat "; $B%9%-%C%W$9$k$K$O(B" skip))
-		     " *")
+			 (concat "* $B%9%-%C%W$9$k$K$O(B" skip "\n"))
+		     "* $B!ZLd![$r%9%/%m!<%k$9$k$K$O(B" sow)
 		  (concat
-		   "* For next question" next "; to quit " quit
+		   "* For next question" next "\n"
+		   "* to quit " quit "\n"
 		   (if (/= skktut-question-count skktut-question-numbers)
-		       (concat "; to skip this question" skip))
-		   " *")))))
+		       (concat "* to skip this question" skip "\n"))
+		   "* to scroll question window" sow)))))
 	    (when skk-tut-use-face
 	      (put-text-property p (point) 'face skk-tut-key-bind-face))
 	    (add-text-properties p (point) plist)
